@@ -1,7 +1,9 @@
 package Module::Install::POE::Test::Loops;
+# vim: ts=3 sw=3 et
 
 use 5.005;
 use strict;
+use warnings;
 use Module::Install::Base;
 use POE::Test::Loops;
 use File::Spec;
@@ -14,7 +16,7 @@ Module::Install::POE::Test::Loops - Install tests for L<POE::Loop>s
 =cut
 
 use vars qw{$VERSION @ISA};
-$VERSION = '0.02';
+$VERSION = '0.03';
 @ISA     = qw{Module::Install::Base};
 
 
@@ -26,31 +28,39 @@ This plugin adds the following Module::Install commands:
 
   gen_loop_tests('t', qw(Glib));
 
-generates tests under the directory F<./t> for the Glib loop.
+Generates tests under the directory F<./t> for the Glib loop. Also adds
+POE::Test::Loops to your configure_requires.
 
 =cut
 
 sub gen_loop_tests {
-  my ($self, @args) = @_;
-  my $dir = shift @args;
-  _gen_loop_tests($self, $dir, \@args);
+   my ($self, $dir, @args) = @_;
+
+   _gen_loop_tests($self, $dir, \@args);
+
+   if (defined $self->configure_requires) {
+      my %c_r = @{$self->configure_requires};
+      return if (defined $c_r{'POE::Test::Loops'});
+   }
+   $self->configure_requires('POE::Test::Loops', '1.002')
 }
 
 sub _gen_loop_tests {
-  my ($self, $dir, $loops) = @_;
-  #return unless $Module::Install::AUTHOR;
+   my ($self, $dir, $loops) = @_;
 
-  my @tests = $self->tests ? (split / /, $self->tests) : 't/*.t';
+   my @tests = $self->tests ? (split / /, $self->tests) : 't/*.t';
 
-  Carp::confess "no dirs given to author_tests"
-    unless @$loops;
+   Carp::confess "no dirs given to gen_loop_tests"
+      unless @$loops;
 
-  POE::Test::Loops::generate($dir, $loops);
+   POE::Test::Loops::generate($dir, $loops);
   
-  $self->tests( join ' ', @tests, map {
-				File::Spec->catfile("$dir/", lc($_), "*.t");
-				      } sort @$loops
-	      );
+   $self->tests(
+      join ' ', @tests,
+         map   {
+                  File::Spec->catfile("$dir/", lc($_), "*.t");
+               } sort @$loops
+   );
 }
 
 1;
